## -----------------------------------------------------------------------------
## Data conversion and upload
## -----------------------------------------------------------------------------
## 
## This script is to create a datadictionary for REDCap, to upload data.
## 
## 

## -----------------------------------------------------------------------------
## Setup
## -----------------------------------------------------------------------------

library(haven)
library(readxl)
library(dplyr)

## -----------------------------------------------------------------------------
## Data file load
## -----------------------------------------------------------------------------

setwd("/Volumes/Data/toorisky/")

dta<-read_dta("Alle apo Aarhus 2018.dta") %>% # Defined dataset
  filter(VaskDiag==1) %>% 
  mutate(treatment=factor(case_when(trombolyse!=2&trombektomi!=2 ~ 0,
                                    trombolyse==2|trombektomi==2 ~ 1)),
         sex.n=factor(ifelse(as.integer(substr(cpr, start = 10, stop = 10)) %%2 == 0, 
                             "female", "male"))) %>%
  left_join(.,read_excel("2022-02-08_ddsc_dataexport.xlsx", sheet = "Patienter"),
            by=c("ForloebID"="forloebid"))%>%
  left_join(.,read_excel("2022-02-08_ddsc_dataexport.xlsx", sheet = "3 mdr. opf."),
            by=c("ForloebID"="ForloebID"))%>%
  mutate(cpr=cpr.x,
         ID=ID.x)%>%
  dplyr::select(-starts_with("cpr."))%>%
  dplyr::select(-starts_with("ID."))

colnames(dta)<-tolower(colnames(dta))
    
## -----------------------------------------------------------------------------
## Fix missing record_id's for upload
## -----------------------------------------------------------------------------

## REDCap pull with minimum data
token=names(suppressWarnings(read.csv("/Users/au301842/nottreated_redcap_token.csv",colClasses = "character")))
uri="https://redcap.au.dk/api/"

library(REDCapR)

redcap <- redcap_read_oneshot(
  redcap_uri   = uri,
  token        = token,
  fields = c("record_id","forloebid")
)$data


## Joining and adding record_id's
dta<-full_join(dta,redcap)

n_na<-length(dta$record_id[is.na(dta$record_id)])
n_id<-max(dta$record_id,na.rm=T)
# filter(!is.na(akut_ind))%>%
dta$record_id[is.na(dta$record_id)]<-(n_id+1):(n_id+n_na) # Simple math

## -----------------------------------------------------------------------------
## Data dictionary
## -----------------------------------------------------------------------------

setwd("/Users/au301842/nottreated/")

icname<-colnames(read.csv("examlpe instrument.csv"))
dd<-data.frame(matrix(ncol = length(icname),
                      nrow=ncol(dta))) ## Data frame to collect all
colnames(dd)<-icname

## Variable names
dd[1]<-colnames(dta)

## Form Name
dd[2]<-"ddsc"

## Field Type
# dd_i[4]<-ifelse(sapply(r_lup[[i]], class)=="factor","radio","text")
dd[4]<-"text"

dd[5]<-colnames(dta)


## -----------------------------------------------------------------------------
## Instrument file
## -----------------------------------------------------------------------------

write.csv(dd,"ddsc_instrument.csv",row.names = FALSE,na="")

## -----------------------------------------------------------------------------
## Dataset export
## -----------------------------------------------------------------------------

write.csv(dta,"ddsc_dataset.csv",row.names = FALSE)
